# _*_ coding: utf-8 _*_
#
# hspylib-clitt v0.9.43
#
# Package: main.clitt.core.tui.minput
"""Package initialization."""

__all__ = [
  'access_type', 
  'field_builder', 
  'form_builder', 
  'form_field', 
  'input_type', 
  'input_validator', 
  'menu_input', 
  'minput', 
  'minput_utils'
]
__version__ = '0.9.43'
